==> odata-client-microsoft-dynamics-0.1.82-sources.jar: microsoft/dynamics/crm/complex/AppModuleCollection.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "AppModuleInfoCollection"})
@JsonInclude(Include.NON_NULL)
public class AppModuleCollection implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("AppModuleInfoCollection")
    protected List<AppModuleInfo> appModuleInfoCollection;

    @JsonProperty("AppModuleInfoCollection@nextLink")
    protected String appModuleInfoCollectionNextLink;

    protected AppModuleCollection() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.AppModuleCollection";
    }

    @Property(name="AppModuleInfoCollection")
    @JsonIgnore
    public CollectionPage<AppModuleInfo> getAppModuleInfoCollection() {
        return new CollectionPage<AppModuleInfo>(contextPath, AppModuleInfo.class, this.appModuleInfoCollection, Optional.ofNullable(appModuleInfoCollectionNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="AppModuleInfoCollection")
    @JsonIgnore
    public CollectionPage<AppModuleInfo> getAppModuleInfoCollection(HttpRequestOptions options) {
        return new CollectionPage<AppModuleInfo>(contextPath, AppModuleInfo.class, this.appModuleInfoCollection, Optional.ofNullable(appModuleInfoCollectionNextLink), Collections.emptyList(), options);
    }

    public AppModuleCollection withUnmappedField(String name, String value) {
        AppModuleCollection _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private List<AppModuleInfo> appModuleInfoCollection;
        private String appModuleInfoCollectionNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder appModuleInfoCollection(List<AppModuleInfo> appModuleInfoCollection) {
            this.appModuleInfoCollection = appModuleInfoCollection;
            this.changedFields = changedFields.add("AppModuleInfoCollection");
            return this;
        }

        public Builder appModuleInfoCollection(AppModuleInfo... appModuleInfoCollection) {
            return appModuleInfoCollection(Arrays.asList(appModuleInfoCollection));
        }

        public Builder appModuleInfoCollectionNextLink(String appModuleInfoCollectionNextLink) {
            this.appModuleInfoCollectionNextLink = appModuleInfoCollectionNextLink;
            this.changedFields = changedFields.add("AppModuleInfoCollection");
            return this;
        }

        public AppModuleCollection build() {
            AppModuleCollection _x = new AppModuleCollection();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.AppModuleCollection";
            _x.appModuleInfoCollection = appModuleInfoCollection;
            _x.appModuleInfoCollectionNextLink = appModuleInfoCollectionNextLink;
            return _x;
        }
    }

    private AppModuleCollection _copy() {
        AppModuleCollection _x = new AppModuleCollection();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.appModuleInfoCollection = appModuleInfoCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AppModuleCollection[");
        b.append("AppModuleInfoCollection=");
        b.append(this.appModuleInfoCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.2.2-sources.jar: microsoft/dynamics/crm/complex/AppModuleCollection.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "AppModuleInfoCollection"})
@JsonInclude(Include.NON_NULL)
public class AppModuleCollection implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("AppModuleInfoCollection")
    protected List<AppModuleInfo> appModuleInfoCollection;

    @JsonProperty("AppModuleInfoCollection@nextLink")
    protected String appModuleInfoCollectionNextLink;

    protected AppModuleCollection() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.AppModuleCollection";
    }

    @Property(name="AppModuleInfoCollection")
    @JsonIgnore
    public CollectionPage<AppModuleInfo> getAppModuleInfoCollection() {
        return new CollectionPage<AppModuleInfo>(contextPath, AppModuleInfo.class, this.appModuleInfoCollection, Optional.ofNullable(appModuleInfoCollectionNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="AppModuleInfoCollection")
    @JsonIgnore
    public CollectionPage<AppModuleInfo> getAppModuleInfoCollection(HttpRequestOptions options) {
        return new CollectionPage<AppModuleInfo>(contextPath, AppModuleInfo.class, this.appModuleInfoCollection, Optional.ofNullable(appModuleInfoCollectionNextLink), Collections.emptyList(), options);
    }

    public AppModuleCollection withUnmappedField(String name, Object value) {
        AppModuleCollection _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private List<AppModuleInfo> appModuleInfoCollection;
        private String appModuleInfoCollectionNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder appModuleInfoCollection(List<AppModuleInfo> appModuleInfoCollection) {
            this.appModuleInfoCollection = appModuleInfoCollection;
            this.changedFields = changedFields.add("AppModuleInfoCollection");
            return this;
        }

        public Builder appModuleInfoCollection(AppModuleInfo... appModuleInfoCollection) {
            return appModuleInfoCollection(Arrays.asList(appModuleInfoCollection));
        }

        public Builder appModuleInfoCollectionNextLink(String appModuleInfoCollectionNextLink) {
            this.appModuleInfoCollectionNextLink = appModuleInfoCollectionNextLink;
            this.changedFields = changedFields.add("AppModuleInfoCollection");
            return this;
        }

        public AppModuleCollection build() {
            AppModuleCollection _x = new AppModuleCollection();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.AppModuleCollection";
            _x.appModuleInfoCollection = appModuleInfoCollection;
            _x.appModuleInfoCollectionNextLink = appModuleInfoCollectionNextLink;
            return _x;
        }
    }

    private AppModuleCollection _copy() {
        AppModuleCollection _x = new AppModuleCollection();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.appModuleInfoCollection = appModuleInfoCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AppModuleCollection[");
        b.append("AppModuleInfoCollection=");
        b.append(this.appModuleInfoCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
